---
title: <span class="badge builder"></span> LineConfig
---
# <span class="badge builder"></span> LineConfig

## Constructor

```python
LineConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> canvas.LineConfig
```

### <span class="badge object-method"></span> color

```python
def color(color: cogbuilder.Builder[common.ColorDimensionConfig]) -> typing.Self
```

### <span class="badge object-method"></span> width

```python
def width(width: float) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [LineConfig](./object-LineConfig.md)
